@@ -63,7 +63,10 @@ class BeaconAPI(object):
 
     @property
     def inifile(self):
-        return os.path.expanduser("~/.config/decipher")
+        DIR = os.path.expanduser("~/.config")
+        try:            os.makedirs(DIR)
+        except OSError: pass
+        return DIR + '/decipher'
 
     @property
     def parser(self):
